## 📖 Melhorias para hoje 
- [X] CoreApp_path em `create_github_function` é anulado e no lugar é adicionado cada argumento individualmente
- [X] adicionar armazenamento avançando de vetores ``reduzindo 40% do consumo`` dos tokens de input
- [X] adicionar Changelog para cada versao do codigo do repositorio

